####FEATURE SELECTION BASED ON THE LOCAL LIFT DEPENDENCE SCALE########
####COVERTYPE: http://archive.ics.uci.edu/ml/datasets/Covertype####

#libraries
library(localift)
library(data.table)
library(xtable)
library(tidyverse)

#read data
cover <- fread("covtype.txt") %>% select(1:10,55)
names(cover) <- c("Elevation","Aspect","Slope","Horizontal_Distance_To_Hydrology",
"Vertical_Distance_To_Hydrology","Horizontal_Distance_To_Roadways","Hillshade_9am","Hillshade_Noon",
"Hillshade_3pm","Horizontal_Distance_To_Fire_Points","Cover_Type")
summary(cover)
cover$Cover_Type <- factor(cover$Cover_Type)

#windows
windows <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "eta",trace = TRUE,
                               quantilesx = c(1:4/5),namesx = as.character(1:5))
View(windows$trace)

#LFmax
max1 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                           quantilesx = c(1:4/5),namesx = as.character(1:5),local = "1")
View(max1$trace)
 
max2 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                            quantilesx = c(1:4/5),namesx = as.character(1:5),local = "2")
View(max2$trace)

max3 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                           quantilesx = c(1:4/5),namesx = as.character(1:5),local = "3")
View(max3$trace)

max4 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                            quantilesx = c(1:4/5),namesx = as.character(1:5),local = "4")
View(max4$trace)

max5 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                            quantilesx = c(1:4/5),namesx = as.character(1:5),local = "5")
View(max5$trace)

max6 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                            quantilesx = c(1:4/5),namesx = as.character(1:5),local = "6")
View(max6$trace)

max7 <- lift.feat.selection(y = cover$Cover_Type,x = cover[,-11],cost = "max",trace = TRUE,
                            quantilesx = c(1:4/5),namesx = as.character(1:5),local = "7")
View(max7$trace)

save(max1,max2,max3,max4,max5,max6,max7,file = "max.RData")
load("max.RData")

max1$trace <- max1$trace[order(max1$trace$Max,decreasing = TRUE),]
max2$trace <- max2$trace[order(max2$trace$Max,decreasing = TRUE),]
max3$trace <- max3$trace[order(max3$trace$Max,decreasing = TRUE),]
max4$trace <- max4$trace[order(max4$trace$Max,decreasing = TRUE),]
max5$trace <- max5$trace[order(max5$trace$Max,decreasing = TRUE),]
max6$trace <- max6$trace[order(max6$trace$Max,decreasing = TRUE),]
max7$trace <- max7$trace[order(max7$trace$Max,decreasing = TRUE),]

#export
unique(windows$trace$XSet[windows$trace$MI == max(windows$trace$MI)]) #selected features Algorithm 1
unique(windows$trace$MI[windows$trace$MI == max(windows$trace$MI)]) #eta Algorithm 1
l <- LiftTable(x = cover[,c(1,4,10)],y = cover$Cover_Type,quantilesx = c(1:4/5),namesx = as.character(1:5),sample = "size")
xtable(l$ltable) #LF Algorithm 1
 
windows$trace <- windows$trace[order(windows$trace$Eta,decreasing = TRUE),]
xtable(windows$trace[1:10,c(1,3,4)]) #windows Algorithm 2
 
xtable(data.frame(rbind(max1$trace[1,c(1,6,7)],max2$trace[1,c(1,6,7)],max3$trace[1,c(1,6,7)],
                        max4$trace[1,c(1,6,7)],max5$trace[1,c(1,6,7)],max6$trace[1,c(1,6,7)],
                        max7$trace[1,c(1,6,7)])))
