% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LiftTable.R
\name{LiftTable}
\alias{LiftTable}
\title{Lift Table}
\usage{
LiftTable(table = NULL, x, y, se = TRUE, local = NULL, w = TRUE,
  windows = "all", block.x = 1, block.y = 1, quantilesx = c(1/3, 2/3),
  namesx = c("1 TertileX", "2 TertileX", "3 TertileX"), quantilesy = c(1/3,
  2/3), namesy = c("1 TertileY", "2 TertileY", "3 TertileY"),
  quantile.type = 7, point.x = "zero", point.y = "zero",
  method = "mahalanobis", p.minkowski = 1, low.min = 0, sample = "se",
  right = TRUE, digits = 3)
}
\arguments{
\item{table}{A contingency table without margins and with row and column names. Needed only if the factor variables are already tabulated.}

\item{x}{A numeric matrix, a factor vector or a numeric vector.}

\item{y}{A numeric matrix, a factor vector or a numeric vector.}

\item{se}{Whether the standard error must be calculated for the lift table and the eta coefficients.}

\item{local}{Must be the name of the category of \emph{y} in which the maximum of the lift must be searched for.
Must be a level of \emph{y} or one of the labels in \emph{namesy}. The \emph{default} is the first category of \emph{y}.}

\item{w}{Whether the \emph{eta} coefficient must be calculated for the \emph{windows} of the support of \emph{U}.}

\item{windows}{In what windows the eta coefficient must be calculated. Must be a list of vectors, in which each vector contain
the name of the categories of \emph{U}. Can be \emph{"all"} for all windows or \emph{"cat"} for the windows that are given by
a single category od \emph{U}}

\item{block.x}{Block factor in which x must be discretize within. The quantiles will be taken inside each block.}

\item{block.y}{Block factor in which y must be discretize within. The quantiles will be taken inside each block.}

\item{quantilesx}{Quantiles in which the variable \emph{x} must be partitioned. Must not contain \emph{0} nor \emph{1}.}

\item{namesx}{Name of the partitions of \emph{x}. Its length must equal \emph{length(quantilesx) + 1}.}

\item{quantilesy}{Quantiles in which the variables \emph{y} must be partitioned. Must not contain \emph{0} nor \emph{1}.}

\item{namesy}{Name of the partitions of \emph{y}. Its length must equal \emph{length(quantilesy) + 1}.}

\item{quantile.type}{An integer between 1 and 9 selecting one of the nine quantile algorithms of the \link[stats]{quantile} function.}

\item{point.x}{Which point to calculate the distances of x from. Must be \emph{'zero'}, \emph{'mean'} for sample mean or
a vector with the dimension of x.}

\item{point.y}{Which point to calculate the distances of y from. Must be \emph{'zero'}, \emph{'mean'} for sample mean or
a vector with the dimension of y.}

\item{method}{Method that should be used to calculate the distance. Must be \emph{'mahalanobis'}, \emph{'euclidean'}, \emph{'maximum'},
\emph{'manhattan'},\emph{'canberra'}, \emph{'binary'} or \emph{'minkowski'}.}

\item{p.minkowski}{The power of the Minkowski distance, if \emph{method = 'minkowski'}.}

\item{low.min}{If \emph{cost = 'max'}, must be an lower bound for the profile relative frequency, so that the algorithm
will search for the rows of the lift table with relative frequency greater than \emph{low.min}.}

\item{sample}{What information about the sample to display in parenthesis on the Lift Table. Must be
\emph{'size'} for sample size, \emph{'joint'} for relative frequency, \emph{'se'} for standard error and \emph{'none'} for
displaying nothing.}

\item{right}{Logical, indicating if the quantile intervals should be closed on the right (and open on the left) or vice versa.}

\item{digits}{Integer indicating the number of significant digits (signif) to be used on the Lift Table.}
}
\value{
\item{ltable}{The Lift Table. Rows are related to \emph{x} and columns to \emph{y}.}

\item{eta}{The dependence measures eta.}

\item{MI}{The normalized Mutual Information of the Lift Table.}

\item{max}{The maximum of the lift on the considered category of \emph{y}.}

\item{xquantile}{The quantile of each observation of \emph{x}.}

\item{yquantile}{The quantile of each observation of \emph{y}.}

\item{se}{The standard error for each lift value.}

\item{cov}{The covariance matrix of the lift function in lexicographical order.}
}
\description{
Lift Table between two groups of variables.
}
\details{
If \emph{x} are \emph{y} are numeric vectors, it computes the Lift Table between
         the discrete random variables \emph{U} and \emph{V} determined from
         the sample quantiles of \emph{x} and \emph{y}, inside each level of the block variables. If \emph{x} or \emph{y}
         are numerical \emph{matrices}, then the Lift Table is computed from the discrete
         random variables \emph{U} and \emph{V} determined from the partition of \emph{(x,y)} by the selected distance method
         based on the sample quantiles, within each level of the block factors. If \emph{x} or \emph{y} are factor vectors,
         the Lift Function is calculated directly from \emph{x} and \emph{y}. If \emph{x} or \emph{y} contain numerical and factor variables
         then the discretization process is made by the quantile discretization of the sample distances from the given point, within
         each level of the factor and block variables.

         If \emph{(U,V)} are discrete and \emph{(u,v)} is a category of \emph{(U,V)} then the Lift Function at such
         category is given by \eqn{L(u,v) = p(u,v) / (pU(u) * pV(v))} in which \emph{p} is
         the relative joint frequency of \emph{(U,V)} and \emph{pU} and \emph{pV}
         are the respective marginal relative frequencies. For more details see the References.
}
\examples{
attach(requirement)
LiftTable(x = SP,y = data.frame(C3,P1))
LiftTable(x = data.frame(C1,C2,C3),y = data.frame(P1,P2))
LiftTable(x = data.frame(iris[,1:4]),y = iris$Species)
}
\references{
Simonis, A., Marcondes, D., Barrera, J. (2017) Feature Selection based on the Local Lift Dependence Scale. \emph{Submitted}
}
