% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/heatmap.lift.R
\name{heatmap.lift}
\alias{heatmap.lift}
\title{Lift Function Heatmap}
\usage{
heatmap.lift(x, y, xlab = "x", ylab = "y", plot.title = " ",
  palette = "Spectral", na.color = "red", contour = TRUE,
  contour.color = "white", contour.alpha = 0.5, contour.bin = 15,
  contour.binwidth = 1, critical.value = 3, quantilesx = c(1/3, 2/3),
  quantilesy = c(1/3, 2/3), breaks = c(1, 2), quantile.type = 7,
  n = length(x), grid = TRUE)
}
\arguments{
\item{x}{A vector of data.}

\item{y}{A vector of data.}

\item{xlab}{Label of the x-axis.}

\item{ylab}{Label of the y-axis.}

\item{plot.title}{Title of the heatmap plot.}

\item{palette}{The color palette to be used on the heatmap. Default is \emph{'Spectral'}.}

\item{na.color}{Color for \emph{NA} values.}

\item{contour}{Logical. Whether to plot the Lift Function contour.}

\item{contour.color}{Color of the Lift Function contour.}

\item{contour.alpha}{Transparency coefficient for the contour plot.}

\item{contour.bin}{Number of bins for the contour plot.}

\item{contour.binwidth}{Width of the bins for the contour plot.}

\item{critical.value}{Critical value in which the Lift Function must be truncated.}

\item{quantilesx}{Quantiles to be marked on the x-axis.}

\item{quantilesy}{Quantiles to be marked on the y-axis.}

\item{breaks}{Breaks of the heatmap legend. Must not contain \emph{0} nor \emph{critical.value} and all values
must be less than the \emph{critical.value}.}

\item{quantile.type}{An integer between 1 and 9 selecting one of the nine quantile algorithms of the \emph{quantile} function.}

\item{n}{Number of equally spaced points at which the density is to be estimated. When n > 512, it is rounded up to a power of 2 during the calculations (as fft is used) and the final result is interpolated by approx. So it almost always makes sense to specify n as a power of two}

\item{grid}{Logical. Whether to plot grid lines representing the sample quantiles.}
}
\value{
\item{plot}{A ggplot2 heatmap.}
}
\description{
Heatmap of the Lift Function.
}
\details{
Given two continuous random variables returns the heatmap of their estimated Lift Function. The heatmap
         paint the support of \emph{(x,y)} according to the values of the Lift Function
         \eqn{L(x,y) = f(x,y)/(g(x) * h(y))} in which \emph{f(x,y)} is the estimated joint density of \emph{(x,y)}
         and \emph{g(x)} and \emph{h(y)} are the respective estimated marginal distributions. If \eqn{L(x,y) > critical.value}
         then \emph{L(x,y) = critical.value}, i.e., \emph{L(x,y)} is truncated at \emph{critical.value}.
}
\examples{
attach(requirement)
heatmap.lift(SP,P2)

}
\references{
Simonis, A., Marcondes, D., Barrera, J. (2017) Feature Selection based on the Local Lift Dependence Scale. \emph{Submitted}
}
