% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lift.feat.selection.R
\name{lift.feat.selection}
\alias{lift.feat.selection}
\title{Lift Featuring Selection Algorithm}
\usage{
lift.feat.selection(y, x, block.x = NULL, block.y = NULL, fix.x = NULL,
  fix.y = NULL, reach.x = "all", reach.y = "all", cost = "eta",
  local = NULL, low.min = 0, windows = "all", trace = FALSE,
  se = FALSE, quantilesx = c(1/3, 2/3), quantile.type = 7,
  namesx = c("1 TertileX", "2 TertileX", "3 TertileX"), quantilesy = c(1/3,
  2/3), namesy = c("1 TertileY", "2 TertileY", "3 TertileY"),
  method = "mahalanobis", p.minkowski = 1, sample = "se",
  point = "zero", min.size = 0, right = TRUE)
}
\arguments{
\item{y}{Data frame in which each column is a sample of a random variable.}

\item{x}{Data frame in which each column is a sample of a random variable.}

\item{block.x}{Block factor in which x must be discretize within. The quantiles will be taken inside each block.}

\item{block.y}{Block factor in which y must be discretize within. The quantiles will be taken inside each block.}

\item{fix.x}{Number of the columns of x that must be considered in all iterations.}

\item{fix.y}{Number of the columns of y that must be considered in all iterations.}

\item{reach.x}{Vector with the sizes of the subsets of x that must be considered. Default is all the power set of x.}

\item{reach.y}{Vector with the sizes of the subsets of y that must be considered. Default is all the power set of y.}

\item{cost}{Cost function to be used. Must be \emph{"MI"} for Mutual Information, \emph{"eta"} for \emph{eta} on windows
or 'max' for the local max.}

\item{local}{If \emph{cost = 'max'}, must be the name of the category of \emph{y} which the maximum of the lift
must be searched for. Must be a level of \emph{y} or one of the labels in \emph{namesy}.}

\item{low.min}{If \emph{cost = 'max'}, must be an lower bound for the profile relative frequency, so that the algorithm
will search for the rows of the lift table with relative frequency greater than \emph{low.min}.}

\item{windows}{In what windows the eta coefficient must be calculated. Can be \emph{"all"} for all windows or \emph{"cat"} for the
windows that are given by a single category od \emph{U}.}

\item{trace}{Logical. Whether to return a data frame with the mutual information and the eta coefficient, along with the Lift Table, for every subset of \emph{y} and \emph{x}.}

\item{se}{Whether the standard error must be calculated for the lift table and the eta coefficients. If \emph{TRUE} the computational time
increases exponentially.}

\item{quantilesx}{Quantiles in which the variables \emph{x} must be partitioned. Must not contain \emph{0} nor \emph{1}.}

\item{quantile.type}{An integer between 1 and 9 selecting one of the nine quantile algorithms of the \emph{quantile} function.}

\item{namesx}{Name of the partitions of \emph{x}. Its length must equal \emph{length(quantilesx) + 1}.}

\item{quantilesy}{Quantiles in which the variables \emph{y} must be partitioned. Must not contain \emph{0} nor \emph{1}.}

\item{namesy}{Name of the partitions of \emph{y}. Its length must equal \emph{length(quantilesy) + 1}.}

\item{method}{Method that should be used to calculate the distance between the sample points
and zero or the sample mean. Must be \emph{'mahalanobis'}, \emph{'euclidean'}, \emph{'maximum'},
\emph{'manhattan'},\emph{'canberra'}, \emph{'binary'} or \emph{'minkowski'}.}

\item{p.minkowski}{The power of the Minkowski distance, if \emph{method = 'minkowski'}.}

\item{sample}{What information about the sample to display in parenthesis on the Lift Table. Must
\emph{'size'} for sample size, \emph{'joint'} for relative frequency and \emph{'none'} for
displaying nothing.}

\item{point}{Which point to calculate the distance from. Must be \emph{'zero'} or \emph{'mean'} for sample mean.}

\item{min.size}{Minimum sample size that can be considered. It will skip all combinations of the \emph{x}
and \emph{y} partitions in which the sample size is less than \emph{min.size}}

\item{right}{Logical, indicating if the quantile intervals should be closed on the right (and open on the left) or vice versa.}
}
\value{
\item{lift}{The \link[localift]{LiftTable} of the selected features.}

\item{MI}{The Mutual information between the returned subsets.}

\item{Eta}{The dependence measures eta between the returned subsets.}

\item{EtaM}{The maximum eta dependence measure in windows of the returned x subset.}

\item{Window}{The window with maximum eta coefficient.}

\item{Max}{The maximum of the lift on the considered category of \emph{y}.}

\item{LevelMax}{The levels of \emph{x} for which the lift is \emph{max}.}

\item{subsetx}{The subset of \emph{x}}

\item{subsety}{The subset of \emph{y}}

\item{xquantile}{The quantile of each observation of \emph{x}.}

\item{yquantile}{The quantile of each observation of \emph{y}.}

\item{trace}{The table with the trace of the algorithm.}

\item{ltables}{The Lift Tables of each iteration.}
}
\description{
Given two sets \emph{x} and \emph{y}, select the subsets of variables that are more dependent.
}
\details{
Given two sets \emph{x} and \emph{y} of random variables, it returns the subsets \emph{x'} of \emph{x} and
         \emph{y'} of \emph{x} for which the Global Eta Coefficient,  or W-Local Eta Coefficient, or the Lift Function
         at a given point is the greatest in comparison to all the other combination of subsets of \emph{x} and \emph{y}.
}
\examples{
attach(requirement)
lift.feat.selection(SP,data.frame(C1,C2,C3,P1,P2),cost = "eta",trace = TRUE,local = "3 TertileY")

}
\references{
Simonis, A., Marcondes, D., Barrera, J. (2017) Feature Selection based on the Local Lift Dependence Scale. \emph{Submitted}
}
