% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mahalanobis.plot.R
\name{mahalanobis.plot}
\alias{mahalanobis.plot}
\title{Mahalanobis Plot}
\usage{
mahalanobis.plot(x, y, g = NULL, g.color = "black", g.name = "Group",
  xlab = "x", ylab = "y", xlim = c(min(data[, 1]), max(data[, 1])),
  ylim = c(min(data[, 2]), max(data[, 2])), quantiles = c(1/3, 2/3),
  names = c("1 Tertile", "2 Tertile", "3 Tertile"), partition = TRUE,
  rectangle = TRUE, rectangle.color = "black", plot.title = " ",
  point = "zero", quantile.type = 7, shape = 16, size = 1.5,
  color = "black")
}
\arguments{
\item{x}{A vector of data.}

\item{y}{A vector of data.}

\item{g}{Grouping factor.}

\item{g.color}{A vector with color names for the ellipses. It must present one color for each level of the grouping factor.}

\item{g.name}{Name of the grouping factor.}

\item{xlab}{Label of the x-axis.}

\item{ylab}{Label of the y-axis.}

\item{xlim}{Limits of the x-axis.}

\item{ylim}{Limits of the y-axis.}

\item{quantiles}{Quantiles of the Mahalanobis partition.}

\item{names}{Name of the partitions. Its length must equal \emph{length(quantiles) + 1}.}

\item{partition}{Logical. Whether the Mahalanobis ellipses are plotted.}

\item{rectangle}{Logical. Whether a rectangle is plotted around the data.}

\item{rectangle.color}{Color of the rectangle.}

\item{plot.title}{Title of the plot.}

\item{point}{Which point to calculate the distance from. Must be \emph{'zero'} or \emph{'mean'} for sample mean.}

\item{quantile.type}{Integer between 1 and 9 selecting one of the nine quantile algorithms of the \emph{quantile} function.}

\item{shape}{ggplot2 shape.}

\item{size}{ggplot2 size.}

\item{color}{Points point color.}
}
\value{
\item{plot}{The dispersion plot.}

\item{quantiles}{The quantile of each observation of \emph{data}.}
}
\description{
Dispersion plot with the Mahalanobis partition ellipses.
}
\details{
Dispersion plot of two random variables with the ellipses of the Mahalanobis partition given
         by the quantiles of a distances to a given point inside each level of a grouping factor.
}
\examples{
attach(requirement)
mahalanobis.plot(C1,C2,xlim = c(0,10),ylim = c(0,10))
}
\references{
Simonis, A., Marcondes, D., Barrera, J. (2017) Feature Selection based on the Local Lift Dependence Scale. \emph{Submitted}
}
